@@ -1,22 +1,26 @@
-#ifndef SMARTCARD_OPENPGPCARD_H
-#define SMARTCARD_OPENPGPCARD_H
 /*  smartcard/openpgpcard.h
 
     This file is part of Kleopatra, the KDE keymanager
     SPDX-FileCopyrightText: 2017 Bundesamt für Sicherheit in der Informationstechnik
     SPDX-FileContributor: Intevation GmbH
+    SPDX-FileCopyrightText: 2020 g10 Code GmbH
+    SPDX-FileContributor: Ingo Klöcker <dev@ingo-kloecker.de>
 
     SPDX-License-Identifier: GPL-2.0-or-later
 */
-
-#include <QMap>
+#ifndef SMARTCARD_OPENPGPCARD_H
+#define SMARTCARD_OPENPGPCARD_H
 
 #include "card.h"
 
+#include <QMap>
+
 namespace Kleo
 {
 namespace SmartCard
 {
+struct KeyPairInfo;
+
 /** Class to work with OpenPGP smartcards or compatible tokens */
 class OpenPGPCard: public Card
 {
@@ -25,22 +29,28 @@ public:
 
     static const std::string AppName;
 
+    static std::string pgpSigKeyRef();
+    static std::string pgpEncKeyRef();
+    static std::string pgpAuthKeyRef();
+
     static std::string pinKeyRef();
     static std::string adminPinKeyRef();
     static std::string resetCodeKeyRef();
 
-    std::string encFpr() const;
-    std::string sigFpr() const;
-    std::string authFpr() const;
+    static const std::vector<KeyPairInfo> & supportedKeys();
+    static QString keyDisplayName(const std::string &keyRef);
 
     void setCardInfo(const std::vector< std::pair<std::string, std::string> > &infos);
 
+    std::string keyFingerprint(const std::string &keyRef) const;
+
     bool operator == (const Card& other) const override;
 
     void setManufacturer(const std::string &manufacturer);
     std::string manufacturer() const;
 
     std::string pubkeyUrl() const;
+
 private:
     QMap <std::string, std::string> mMetaInfo;
     std::string mManufacturer;
