@@ -37,25 +37,24 @@ public:
     void setCard(const SmartCard::NetKeyCard *card);
 
 private:
-    void handleResult(const GpgME::Error &err, QPushButton *btn);
-    void doChangePin(bool sigG);
-
-private Q_SLOTS:
-    void setSigGPinSettingResult(const GpgME::Error &err);
-    void setNksPinSettingResult(const GpgME::Error &err);
+    void doChangePin(const std::string &keyRef);
+    void createKeyFromCardKeys();
+    void createCSR();
 
 private:
     std::string mSerialNumber;
-    QLabel *mSerialNumberLabel,
-           *mVersionLabel,
-           *mLearnKeysLabel,
-           *mErrorLabel;
-    NullPinWidget *mNullPinWidget;
-    QPushButton *mLearnKeysBtn,
-                *mChangeNKSPINBtn,
-                *mChangeSigGPINBtn;
-    KeyTreeView *mTreeView;
-    QScrollArea *mArea;
+    QLabel *mSerialNumberLabel = nullptr,
+           *mVersionLabel = nullptr,
+           *mLearnKeysLabel = nullptr,
+           *mErrorLabel = nullptr;
+    NullPinWidget *mNullPinWidget = nullptr;
+    QPushButton *mLearnKeysBtn = nullptr,
+                *mKeyForCardKeysButton = nullptr,
+                *mCreateCSRButton = nullptr,
+                *mChangeNKSPINBtn = nullptr,
+                *mChangeSigGPINBtn = nullptr;
+    KeyTreeView *mTreeView = nullptr;
+    QScrollArea *mArea = nullptr;
 };
 } // namespace Kleo
 
